Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1561)

Unified Diff: chrome/browser/ui/webui/downloads_dom_handler.h

Issue 1325853006: MD Downloads: wrap some <paper-buttons>s in <template is="dom-if"> (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/downloads_dom_handler.h
diff --git a/chrome/browser/ui/webui/downloads_dom_handler.h b/chrome/browser/ui/webui/downloads_dom_handler.h
index 495d32c7c03bd31990bed2728fe8ccda9a450890..6dd0dfeaeedbe8e2bdbb450dfac9351338549fe7 100644
--- a/chrome/browser/ui/webui/downloads_dom_handler.h
+++ b/chrome/browser/ui/webui/downloads_dom_handler.h
@@ -65,8 +65,8 @@ class DownloadsDOMHandler : public content::WebUIMessageHandler,
// wishes to discard (remove) a dangerous file.
void HandleDiscardDangerous(const base::ListValue* args);
- // Callback for the "show" message - shows the file in explorer.
- void HandleShow(const base::ListValue* args);
+ // Callback for the "showInFolder" message - shows the file in explorer.
+ void HandleShowInFolder(const base::ListValue* args);
// Callback for the "pause" message - pauses the file download.
void HandlePause(const base::ListValue* args);

Powered by Google App Engine
This is Rietveld 408576698